@@ -1,5 +1,7 @@
+from django.http.response import JsonResponse
+
 def login_valid():  
-    return "Valid User"
+    return JsonResponse("Valid User",safe=False)
 
 def loginApi_invalid():
     return "INVALID USER"
